gchecky.model.add_tracking_data_t

Package gchecky :: Module model :: Class add_tracking_data_t |
[hide private]
[frames] | no frames]

# Class add_tracking_data_t

source code

    object --+
             |
     gxml.Node --+
                 |
     gxml.Document --+
                     |
      abstract_order_t --+
                         |
                        add_tracking_data_t

Represents a tag containing a request to add a shipper's tracking number to an order.

    >>> test_document(
    ...     add_tracking_data_t(
    ...         google_order_number = '841171949013218',
    ...         tracking_data = tracking_data_t(
    ...             carrier = 'UPS',
    ...             tracking_number = 'Z9842W69871281267'
    ...         )
    ...     )
    ... ,
    ...     '''
    ...     <add-tracking-data xmlns="http://checkout.google.com/schema/2"
    ...                        google-order-number="841171949013218">
    ...       <tracking-data>
    ...         <tracking-number>Z9842W69871281267</tracking-number>
    ...         <carrier>UPS</carrier>
    ...       </tracking-data>
    ...     </add-tracking-data>
    ...     '''
    ... )

Nested Classes | [hide private]
Inherited from `gxml.Document`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Document`: `__str__`, `toxml` Inherited from `gxml.Node`: `__eq__`, `__init__`, `__neq__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`

Class Methods | [hide private]
Inherited from `gxml.Document`: `fromxml` Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
| tag_name = ``'``add-tracking-data``'`` The document's unique xml tag name.
| tracking_data = `Node:PATH(tracking-data):REQ:{ tracking_data_t }`
| _fields = ``{``'``google_order_number``'``:` ID:PATH(@google-order-number`...`` list of meta-Fields of this class.
Inherited from `abstract_order_t`: `google_order_number`

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### _fields list of meta-Fields of this class. Value:
      {'google_order_number': ID:PATH(@google-order-number):REQ:EMPTY,
       'tracking_data': Node:PATH(tracking-data):REQ:{ tracking_data_t }}